@@ -50,7 +50,7 @@ public abstract class AbstractHomeProducer implements HomeModelProvider {
     public HomeModel get() {
         final HomeModel model = new HomeModel(translationService.format(Constants.Heading),
                                               translationService.format(Constants.SubHeading),
-                                              "images/product_home_bg.svg");
+                                              "images/product_home_bg.png");
 
         model.addShortcut(createDesignShortcut());
         model.addShortcut(createDeployShortcut());
@@ -97,8 +97,8 @@ public abstract class AbstractHomeProducer implements HomeModelProvider {
     }
 
     protected HomeShortcut createDeployShortcut() {
-        final HomeShortcutLink deployments = new HomeShortcutLink(translationService.format(Constants.Deployments),
-                                                                  DEPLOYMENTS);
+        final HomeShortcutLink deployments = new HomeShortcutLink(translationService.format(Constants.Provisioning),
+                                                                  PROVISIONING);
         final HomeShortcutLink servers = new HomeShortcutLink(translationService.format(Constants.Servers),
                                                               SERVER_MANAGEMENT);
         final boolean isDeploymentsAuthorized = shortcutHelper.authorize(deployments.getPerspectiveIdentifier());
