@@ -135,11 +135,17 @@ public class KieWorkbenchEntryPointTest {
         kieWorkbenchEntryPoint.init();
 
         verify(workbench).addStartupBlocker(KieWorkbenchEntryPoint.class);
-        verify(permissionTreeSetup).configureTree();
         verify(navTreeEditor).setMaxLevels(NavTreeDefinitions.GROUP_WORKBENCH,
                                            2);
     }
 
+    @Test
+    public void testInitializeWorkbench(){
+        kieWorkbenchEntryPoint.initializeWorkbench();
+
+        verify(permissionTreeSetup).configureTree();
+    }
+
     @Test
     public void setupMenuTest() {
         kieWorkbenchEntryPoint.setupMenu();
@@ -223,5 +229,17 @@ public class KieWorkbenchEntryPointTest {
                      track);
         assertEquals(taskDashboard.getParent(),
                      track);
+
+        assertFalse(design.isModifiable());
+        assertFalse(pages.isModifiable());
+    }
+
+    @Test
+    public void testSetupAdminPage(){
+        kieWorkbenchEntryPoint.setupAdminPage();
+
+        verify(adminPageHelper).setup(false,
+                                      true,
+                                      false);
     }
 }
